@@ -243,6 +243,8 @@ pub struct QueryResponsePayload {
     pub vendor_identification: Option<String>,
 
     #[serde(rename = "0x420088")]
+    #[serde(skip_deserializing)] // We don't support this yet
+    #[serde(default)]
     pub server_information: Option<ServerInformation>,
 }
 
@@ -255,9 +257,9 @@ pub struct RNGRetrieveResponsePayload {
 }
 
 ///  See KMIP 1.0 section 4.24 [Server Information](https://docs.oasis-open.org/kmip/spec/v1.0/os/kmip-spec-1.0-os.html#_Toc262581232).
-#[derive(Clone, Debug, Deserialize, PartialEq, Eq)]
-#[serde(rename = "0x420088", transparent)]
-pub struct ServerInformation(#[serde(with = "serde_bytes")] pub Option<Vec<u8>>);
+#[derive(Clone, Debug, Deserialize, PartialEq, Eq, Default)]
+#[serde(rename = "0x420088")]
+pub struct ServerInformation;
 
 ///  See KMIP 1.1 section 4.26 [Discover Versions](https://docs.oasis-open.org/kmip/spec/v1.1/cs01/kmip-spec-v1.1-cs01.html#_Toc332787652).
 #[derive(Clone, Debug, Deserialize, PartialEq, Eq)]
@@ -377,13 +379,16 @@ pub struct MessageExtension {
     pub criticality_indicator: bool,
 
     #[serde(rename = "0x42009C")]
+    #[serde(skip_deserializing)] // We don't support this yet
+    #[serde(default)]
     pub vendor_extension: VendorExtension,
 }
 
 ///  See KMIP 1.0 section 6.16 [Message Extension](https://docs.oasis-open.org/kmip/spec/v1.0/os/kmip-spec-1.0-os.html#_Toc262581254).
-#[derive(Clone, Debug, Deserialize, PartialEq, Eq)]
-#[serde(rename = "0x42009C", transparent)]
-pub struct VendorExtension(#[serde(with = "serde_bytes")] pub Option<Vec<u8>>);
+#[derive(Clone, Debug, Deserialize, PartialEq, Eq, Default)]
+// #[serde(rename = "0x42009C", transparent)]
+#[serde(rename = "0x42009C")]
+pub struct VendorExtension;
 
 ///  See KMIP 1.0 section 7.1 [Message Structure](https://docs.oasis-open.org/kmip/spec/v1.0/os/kmip-spec-1.0-os.html#_Toc262581256).
 #[derive(Clone, Debug, Deserialize, PartialEq, Eq)]
